@@ -1,7 +1,7 @@
 import itertools
 import math
 
-from django.core.exceptions import EmptyResultSet
+from django.core.exceptions import EmptyResultSet, FullResultSet
 from django.db.models.expressions import Case, Expression, Func, Value, When
 from django.db.models.fields import (
     BooleanField,
@@ -128,7 +128,7 @@ class Lookup(Expression):
     def rhs_is_direct_value(self):
         return not hasattr(self.rhs, "as_sql")
 
-    def get_group_by_cols(self, alias=None):
+    def get_group_by_cols(self):
         cols = []
         for source in self.get_source_expressions():
             cols.extend(source.get_group_by_cols())
@@ -309,7 +309,7 @@ class FieldGetDbPrepValueIterableMixin(FieldGetDbPrepValueMixin):
         return sql, tuple(params)
 
 
-class PostgresOperatorLookup(FieldGetDbPrepValueMixin, Lookup):
+class PostgresOperatorLookup(Lookup):
     """Lookup defined by operators on PostgreSQL."""
 
     postgres_operator = None
@@ -325,8 +325,8 @@ class PostgresOperatorLookup(FieldGetDbPrepValueMixin, Lookup):
 class Exact(FieldGetDbPrepValueMixin, BuiltinLookup):
     lookup_name = "exact"
 
-    def process_rhs(self, compiler, connection):
-        from django.db.models.sql.query import Query
+    def get_prep_lookup(self):
+        from django.db.models.sql.query import Query  # avoid circular import
 
         if isinstance(self.rhs, Query):
             if self.rhs.has_limit_one():
@@ -338,7 +338,7 @@ class Exact(FieldGetDbPrepValueMixin, BuiltinLookup):
                     "The QuerySet value for an exact lookup must be limited to "
                     "one result using slicing."
                 )
-        return super().process_rhs(compiler, connection)
+        return super().get_prep_lookup()
 
     def as_sql(self, compiler, connection):
         # Avoid comparison against direct rhs if lhs is a boolean value. That
@@ -415,6 +415,16 @@ class IntegerLessThan(IntegerFieldFloatRounding, LessThan):
 class In(FieldGetDbPrepValueIterableMixin, BuiltinLookup):
     lookup_name = "in"
 
+    def get_prep_lookup(self):
+        from django.db.models.sql.query import Query  # avoid circular import
+
+        if isinstance(self.rhs, Query):
+            self.rhs.clear_ordering(clear_default=True)
+            if not self.rhs.has_select_fields:
+                self.rhs.clear_select_clause()
+                self.rhs.add_fields(["pk"])
+        return super().get_prep_lookup()
+
     def process_rhs(self, compiler, connection):
         db_rhs = getattr(self.rhs, "_db", None)
         if db_rhs is not None and db_rhs != connection.alias:
@@ -439,26 +449,7 @@ class In(FieldGetDbPrepValueIterableMixin, BuiltinLookup):
             sqls, sqls_params = self.batch_process_rhs(compiler, connection, rhs)
             placeholder = "(" + ", ".join(sqls) + ")"
             return (placeholder, sqls_params)
-        else:
-            from django.db.models.sql.query import Query  # avoid circular import
-
-            if isinstance(self.rhs, Query):
-                query = self.rhs
-                query.clear_ordering(clear_default=True)
-                if not query.has_select_fields:
-                    query.clear_select_clause()
-                    query.add_fields(["pk"])
-
-            return super().process_rhs(compiler, connection)
-
-    def get_group_by_cols(self, alias=None):
-        cols = self.lhs.get_group_by_cols()
-        if hasattr(self.rhs, "get_group_by_cols"):
-            if not getattr(self.rhs, "has_select_fields", True):
-                self.rhs.clear_select_clause()
-                self.rhs.add_fields(["pk"])
-            cols.extend(self.rhs.get_group_by_cols())
-        return cols
+        return super().process_rhs(compiler, connection)
 
     def get_rhs_op(self, connection, rhs):
         return "IN %s" % rhs
@@ -577,7 +568,12 @@ class IsNull(BuiltinLookup):
             raise ValueError(
                 "The QuerySet value for an isnull lookup must be True or False."
             )
-        sql, params = compiler.compile(self.lhs)
+        if isinstance(self.lhs, Value) and self.lhs.value is None:
+            if self.rhs:
+                raise FullResultSet
+            else:
+                raise EmptyResultSet
+        sql, params = self.process_lhs(compiler, connection)
         if self.rhs:
             return "%s IS NULL" % sql, params
         else:
